import { Server } from "socket.io";
import { TSocket } from "../../../utilities/Types";
import { writeFile } from "node:fs/promises";
import path from "path";
import fs from "fs/promises";
import objectRepository from '../../../repositories/ObjectRepository'

interface IObjectData {
    [key: string]: Buffer;
}

/**
 * Handle game master upload object event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
    socket.on('gm:object:upload', async (data: IObjectData, callback: (response: boolean) => void) => {
        try {
            if (socket.character?.role !== 'gm') {
                callback(false);
                return;
            }

            const public_folder = path.join(process.cwd(), 'public', 'objects');

            // Ensure the folder exists
            await fs.mkdir(public_folder, { recursive: true });

            const uploadPromises = Object.entries(data).map(async ([key, objectData]) => {
                const object = await objectRepository.create('New object', 0, 0);
                const uuid = object.id;
                const filename = `${uuid}.png`;
                const finalFilePath = path.join(public_folder, filename);
                await writeFile(finalFilePath, objectData);
            });

            await Promise.all(uploadPromises);

            callback(true);
        } catch (error) {
            console.error('Error uploading tile:', error);
            callback(false);
        }
    });
}