import { Server } from "socket.io";
import {TSocket} from "../../../utilities/Types";
import path from "path";
import fs from "fs";
import TileRepository from '../../../repositories/TileRepository'

interface IPayload {
    tile: string;
}

/**
 * Handle game master remove tile event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
    socket.on('gm:tile:remove', async (data: IPayload, callback: (response: boolean) => void) => {

        if (socket.character?.role !== 'gm') {
            return;
        }

        try {
            await TileRepository.delete(data.tile);

            // get root path
            const public_folder = path.join(process.cwd(), 'public', 'tiles');

            // remove the tile from the disk
            const finalFilePath = path.join(public_folder, data.tile + '.png');
            fs.unlink(finalFilePath, (err) => {
                if (err) {
                    console.log(err);
                    callback(false);
                    return;
                }

                callback(true);
            });
        } catch (e) {
            console.log(e);
            callback(false);
        }
    });
}